/*
    Font filters implementation.
    Copyright (C) 2020  Alessandro Accattini

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *****************************************************************************
 *
 *
 * $Header$
 *
 *
 *
 * REVISION HISTORY:
 * $Log$
 */

/**  \file filters.h
     \author Alessandro Accattini
     \date 2020
     \brief Font filters implementation.
 */



#ifndef __FILTERS_H
#define __FILTERS_H		1


#include "fontdesc.h"				// font descriptor data type
   
/***************************************************************************/
/* define pubblici */

/***************************************************************************/
/* macro pubbliche */

/***************************************************************************/
/* strutture pubbliche */

/***************************************************************************/
/* costanti pubbliche */

/***************************************************************************/
/* variabili pubbliche */

/***************************************************************************/
/* funzioni pubbliche */

FontDesc_t *NewFont(const FontDesc_t *Font);
  /**< \brief Allocates a new modifiable font.
       \param Font[in]   Starting font.
       \return           An in-place modifiable font.

       Allocates a new modifiable font. All fonts are declared as constants,
       this function dulicates font declaration in RAM to be in-place
       modifiable. All fonts created by this function can be deallocated
       calling free().
   */


FontDesc_t *RightShift(FontDesc_t *Font,uint32_t Shift);
  /**< \brief Right shift all font data.
       \param Font[in]   In-place modifiable font (see \ref NewFont()).
       \param Shift[in]  Shift amount (in pixel).
       \return           Modified font.
   */

FontDesc_t *LeftShift(FontDesc_t *Font,uint32_t Shift);
  /**< \brief Left shift all font data.
       \param Font[in]   In-place modifiable font (see \ref NewFont()).
       \param Shift[in]  Shift amount (in pixel).
       \return           Modified font.
   */

FontDesc_t *FlipLeftToRight(FontDesc_t *Font);
  /**< \brief Flips characters left to right.
       \param Font[in]   In-place modifiable font (see \ref NewFont()).
       \return           Modified font.
   */

FontDesc_t *RotateRight(FontDesc_t *Font);
  /**< \brief Rotates all characters shapes 90 degrees clock-wise.
       \param Font[in]   In-place modifiable font (see \ref NewFont()).
       \return           Modified font.
   */

FontDesc_t *RotateLeft(FontDesc_t *Font);
  /**< \brief Rotates all characters shapes 90 degrees counter-clock-wise.
       \param Font[in]   In-place modifiable font (see \ref NewFont()).
       \return           Modified font.
   */

FontDesc_t *CharCut(FontDesc_t *Font,uint32_t Retain);
  /**< \brief Limits the number of bytes per char.
       \param Font[in]   In-place modifiable font (see \ref NewFont()).
       \param Retain[in] Number of bytes to retain for each char.
       \return           Modified font.
   */

/***************************************************************************/
#endif

/* $Source$ */

